@@ -16,7 +16,7 @@ use vars qw($VERSION);
 use Image::ExifTool qw(:DataAccess :Utils);
 use Image::ExifTool::XMP;
 
-$VERSION = '1.18';
+$VERSION = '1.20';
 
 sub ProcessXtra($$$);
 
@@ -88,12 +88,13 @@ sub ProcessXtra($$$);
     Rating => {
         Name => 'RatingPercent',
         Notes => q{
-            called Rating by the spec.  XMP-xmp:Rating values of 1,2,3,4 and 5 stars
-            correspond to RatingPercent values of 1,25,50,75 and 99 respectively
+            XMP-xmp:Rating values of 1,2,3,4 and 5 stars correspond to RatingPercent
+            values of 1,25,50,75 and 99 respectively
         },
     },
     CreatorAppId             => { Name => 'CreatorAppID' },
     CreatorOpenWithUIOptions => { },
+    ItemSubType              => { },
 );
 
 # Microsoft Photo 1.1 schema properties (MP1 - written as 'prefix0' by MSPhoto) (ref PH)
@@ -191,7 +192,8 @@ my %sRegions = (
 
 # Xtra tags written in MP4 files written by Microsoft Windows Media Player
 # (ref http://msdn.microsoft.com/en-us/library/windows/desktop/dd562330(v=VS.85).aspx)
-# Note: These tags are closely related to Image::ExifTool::ASF::ExtendedDescr
+# Note: These tags are closely related to tags in Image::ExifTool::ASF::ExtendedDescr
+#       and Image::ExifTool::WTV::Metadata
 %Image::ExifTool::Microsoft::Xtra = (
     PROCESS_PROC => \&ProcessXtra,
     GROUPS => { 0 => 'QuickTime', 2 => 'Video' },
@@ -882,7 +884,7 @@ Microsoft-specific EXIF and XMP tags.
 
 =head1 AUTHOR
 
-Copyright 2003-2017, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2018, Phil Harvey (phil at owl.phy.queensu.ca)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
